/*******************************************************************************
 * Copyright (c) 2009 Mia-Software.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Nicolas Bros (Mia-Software) - initial API and implementation
 *    
 *******************************************************************************/

package org.eclipse.gmt.modisco.common.editor.editors;

import org.eclipse.gmt.modisco.common.editor.util.ImageProvider;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.ToolBar;
import org.eclipse.swt.widgets.ToolItem;

public class TreeToolBar {
	
	private final ToolBar toolBar;
	private final EcoreEditor editor;
	private ToolItem btnShowEmptyLinks;
	private ToolItem btnSortInstances;
	private ToolItem btnSortLinks;
	private ToolItem btnShowDerivedLinks;
	private ToolItem btnShowFullQualifiedNames;
	private ToolItem btnShowMultiplicity;
	private ToolItem btnShowOppositeLinks;
	private ToolItem btnShowContainer;
	private ToolItem btnShowAttributes;
	private ToolItem btnShowEmptyAttributes;

	public TreeToolBar(Composite parent, EcoreEditor editor) {
		this.editor = editor;
		toolBar = new ToolBar(parent, SWT.NONE);
		GridData toolBarGridData = new GridData();
		toolBarGridData.grabExcessHorizontalSpace = false;
		toolBarGridData.horizontalAlignment = SWT.FILL;
		toolBar.setLayoutData(toolBarGridData);

		createToolButtons();
		initialize();
	}

	private void createToolButtons() {
		btnShowEmptyLinks = new ToolItem(toolBar, SWT.CHECK);
		btnShowEmptyLinks.setToolTipText("Show Empty Links");
		btnShowEmptyLinks.setImage(ImageProvider.getInstance().getEmptyLinksIcon());
		btnShowEmptyLinks.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) {
				editor.setShowEmptyLinks(btnShowEmptyLinks.getSelection());
			}
		});
		
		btnShowDerivedLinks = new ToolItem(toolBar, SWT.CHECK);
		btnShowDerivedLinks.setToolTipText("Show Derived Links");
		btnShowDerivedLinks.setImage(ImageProvider.getInstance().getShowDerivedLinksIcon());
		btnShowDerivedLinks.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) {
				editor.setShowDerivedLinks(btnShowDerivedLinks.getSelection());
			}
		});
		
		btnSortInstances = new ToolItem(toolBar, SWT.CHECK);
		btnSortInstances.setToolTipText("Sort Instances");
		btnSortInstances.setImage(ImageProvider.getInstance().getSortInstancesIcon());
		btnSortInstances.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) {
				editor.setSortInstances(btnSortInstances.getSelection());
			}
		});
		
		btnSortLinks = new ToolItem(toolBar, SWT.CHECK);
		btnSortLinks.setToolTipText("Sort Links");
		btnSortLinks.setImage(ImageProvider.getInstance().getSortLinksIcon());
		btnSortLinks.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) {
				editor.setSortLinks(btnSortLinks.getSelection());
			}
		});

		btnShowFullQualifiedNames = new ToolItem(toolBar, SWT.CHECK);
		btnShowFullQualifiedNames.setToolTipText("Show Full Qualified Names");
		btnShowFullQualifiedNames.setImage(ImageProvider.getInstance().getShowFullQualifiedNamesIcon());
		btnShowFullQualifiedNames.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) {
				editor.setShowFullQualifiedNames(btnShowFullQualifiedNames.getSelection());
			}
		});
		
		btnShowMultiplicity = new ToolItem(toolBar, SWT.CHECK);
		btnShowMultiplicity.setToolTipText("Show Multiplicity");
		btnShowMultiplicity.setImage(ImageProvider.getInstance().getShowMultiplicityIcon());
		btnShowMultiplicity.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) {
				editor.setShowMultiplicity(btnShowMultiplicity.getSelection());
			}
		});
		
		btnShowOppositeLinks = new ToolItem(toolBar, SWT.CHECK);
		btnShowOppositeLinks.setToolTipText("Show Opposite Links");
		btnShowOppositeLinks.setImage(ImageProvider.getInstance().getShowOppositeLinksIcon());
		btnShowOppositeLinks.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) {
				editor.setShowOppositeLinks(btnShowOppositeLinks.getSelection());
			}
		});
		
		btnShowContainer = new ToolItem(toolBar, SWT.CHECK);
		btnShowContainer.setToolTipText("Show Container");
		btnShowContainer.setImage(ImageProvider.getInstance().getContainerIcon());
		btnShowContainer.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) {
				editor.setShowContainer(btnShowContainer.getSelection());
			}
		});

		btnShowAttributes = new ToolItem(toolBar, SWT.CHECK);
		btnShowAttributes.setToolTipText("Show Attributes");
		btnShowAttributes.setImage(ImageProvider.getInstance().getAttributeIcon());
		btnShowAttributes.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) {
				editor.setShowAttributes(btnShowAttributes.getSelection());
				btnShowEmptyAttributes.setEnabled(btnShowAttributes.getSelection());
			}
		});

		btnShowEmptyAttributes = new ToolItem(toolBar, SWT.CHECK);
		btnShowEmptyAttributes.setToolTipText("Show Empty Attributes");
		btnShowEmptyAttributes.setImage(ImageProvider.getInstance().getEmptyAttributeIcon());
		btnShowEmptyAttributes.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) {
				editor.setShowEmptyAttributes(btnShowEmptyAttributes.getSelection());
			}
		});
}
	
	private void initialize() {
		btnShowEmptyLinks.setSelection(this.editor.isShowEmptyLinks());
		btnSortInstances.setSelection(this.editor.isSortInstances());
		btnSortLinks.setSelection(this.editor.isSortLinks());
		btnShowDerivedLinks.setSelection(this.editor.isShowDerivedLinks());
		btnShowFullQualifiedNames.setSelection(this.editor.isShowFullQualifiedNames());
		btnShowMultiplicity.setSelection(this.editor.isShowMultiplicity());
		btnShowOppositeLinks.setSelection(this.editor.isShowOppositeLinks());
		btnShowContainer.setSelection(this.editor.isShowContainer());
		btnShowAttributes.setSelection(this.editor.isShowAttributes());
		btnShowEmptyAttributes.setSelection(this.editor.isShowEmptyAttributes());
		
		btnShowEmptyAttributes.setEnabled(this.editor.isShowAttributes());
	}	
}
